pydevDAG._readwrite._readwrite module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._readwrite package »

# pydevDAG._readwrite._readwrite module

## pydevDAG._readwrite._readwrite

Tools to write out a graph or read one in.

class `pydevDAG._readwrite._readwrite.` `JSONReader`

  Bases: `object`

  Read graph from a file.

  classmethod `read`(instream)

    Read a graph from an input stream

    Parameters: | instream – the input stream
    Returns: | a graph corresponding to the JSON data in the stream

  static `readin`(data)

    Read data from a string input.

    Parameters: | data – the JSON formatted data
    Returns: | the graph
    Return type: | DiGraph

class `pydevDAG._readwrite._readwrite.` `JSONWriter`

  Bases: `object`

  Write graph to a file.

  static `write`(graph, out)

    Write a graph to an output stream.

    Parameters: | graph (DiGraph) – a graph out – an output stream

`pydevDAG._readwrite._readwrite.` `Reader`

  alias of `JSONReader`

`pydevDAG._readwrite._readwrite.` `Writer`

  alias of `JSONWriter`

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._readwrite package »